@@ -1,6 +1,6 @@
 import math
 from abc import ABC, abstractmethod
-from functools import lru_cache
+from functools import lru_cache, partial
 from itertools import combinations
 
 import numpy as np
@@ -38,10 +38,28 @@ class Explainer(ABC):
 
 
 class ShapExplainer(Explainer):
-    def __init__(self, func, X):
-        self.func = func
-        self.X = self._create_background_data(X)
-        self.n_col = len(X.columns)
+    def __init__(self, func, X, profile_columns=None):
+        if profile_columns is None:
+            profile_columns = X.columns
+
+        if len(X.columns) > len(profile_columns):
+
+            def func_fused(X_profile_columns, X_background):
+                X_combined = X_profile_columns.copy()
+                for col in X_background.columns:
+                    X_combined[col] = X_background.loc[0, col]
+                X_combined = X_combined.reindex(columns=X.columns)
+                return func(X_combined)
+
+            X_background = self._create_background_data(X.drop(columns=profile_columns))
+            self.func = partial(func_fused, X_background=X_background)
+            self.X = self._create_background_data(X[profile_columns])
+            self.n_col = len(profile_columns)
+
+        else:
+            self.func = func
+            self.X = self._create_background_data(X)
+            self.n_col = len(X.columns)
 
     @staticmethod
     def _create_background_data(X):
